import * as react from 'react';
import { InputHTMLAttributes, ReactNode, FC } from 'react';
import { IconCSS, IconProps } from '@pikas-ui/icons';
import { PikasCSS, PikasShadow, BorderRadius, PikasFontSize, PikasColor } from '@pikas-ui/styles';
import { TooltipCSS } from '@pikas-ui/tooltip';

declare const multiInputFieldType: {
    readonly color: true;
    readonly date: true;
    readonly 'datetime-local': true;
    readonly email: true;
    readonly hidden: true;
    readonly month: true;
    readonly number: true;
    readonly password: true;
    readonly search: true;
    readonly tel: true;
    readonly text: true;
    readonly time: true;
    readonly url: true;
    readonly week: true;
};
type MultiInputFieldType = keyof typeof multiInputFieldType;
declare const multiInputFieldPadding: {
    readonly xs: true;
    readonly sm: true;
    readonly md: true;
    readonly lg: true;
    readonly xl: true;
};
type MultiInputFieldPadding = keyof typeof multiInputFieldPadding;
declare const multiInputFieldGap: {
    readonly xs: true;
    readonly sm: true;
    readonly md: true;
    readonly lg: true;
    readonly xl: true;
};
type MultiInputFieldGap = keyof typeof multiInputFieldGap;
type MultiInputFieldCSS = {
    container?: PikasCSS;
    inputContainer?: PikasCSS;
    inputContent?: PikasCSS;
    input?: PikasCSS;
    left?: PikasCSS;
    right?: PikasCSS;
    leftIcon?: IconCSS;
    rightIcon?: IconCSS;
    infoTooltip?: TooltipCSS;
    infoIcon?: IconCSS;
    label?: PikasCSS;
    description?: PikasCSS;
    textError?: PikasCSS;
    required?: PikasCSS;
    badge?: PikasCSS;
};
type MultiInputFieldProps = InputHTMLAttributes<HTMLInputElement> & {
    css?: MultiInputFieldCSS;
    id?: string;
    label?: ReactNode | string;
    boxShadow?: PikasShadow | 'none';
    borderRadius?: BorderRadius;
    padding?: MultiInputFieldPadding;
    gap?: MultiInputFieldGap;
    fontSize?: PikasFontSize;
    borderColorName?: PikasColor;
    borderColorHex?: string;
    borderWidth?: number;
    colorName?: PikasColor;
    colorHex?: string;
    placeholderColorName?: PikasColor;
    placeholderColorHex?: string;
    backgroundColorName?: PikasColor;
    backgroundColorHex?: string;
    textError?: string;
    onChange?: (values: string[]) => void;
    autoComplete?: string;
    LeftIcon?: FC<IconProps>;
    RightIcon?: FC<IconProps>;
    leftIconColorName?: PikasColor;
    leftIconColorHex?: string;
    rightIconColorName?: PikasColor;
    rightIconColorHex?: string;
    leftIconSize?: number;
    rightIconSize?: number;
    leftChildren?: ReactNode;
    rightChildren?: ReactNode;
    min?: number;
    max?: number;
    outline?: boolean;
    description?: string;
    width?: number | string;
    maxWidth?: number | string;
    minWidth?: number | string;
    info?: ReactNode;
    data?: DOMStringMap;
    type?: MultiInputFieldType;
    defaultValues?: string[];
};
declare const MultiInputField: react.ForwardRefExoticComponent<InputHTMLAttributes<HTMLInputElement> & {
    css?: MultiInputFieldCSS | undefined;
    id?: string | undefined;
    label?: ReactNode | string;
    boxShadow?: "none" | "ELEVATION_1" | "ELEVATION_2" | "ELEVATION_3" | "ELEVATION_4" | "ELEVATION_TOP_1" | "ELEVATION_TOP_2" | "ELEVATION_TOP_3" | "ELEVATION_TOP_4" | "ELEVATION_TOP_5" | "ELEVATION_TOP_6" | "ELEVATION_BOTTOM_1" | "ELEVATION_BOTTOM_2" | "ELEVATION_BOTTOM_3" | "ELEVATION_BOTTOM_4" | "ELEVATION_BOTTOM_5" | "ELEVATION_BOTTOM_6" | "DIMINUTION_1" | "DIMINUTION_2" | "DIMINUTION_3" | "DIMINUTION_4" | "DIMINUTION_5" | undefined;
    borderRadius?: "none" | "xs" | "sm" | "md" | "lg" | "xl" | "round" | undefined;
    padding?: "xs" | "sm" | "md" | "lg" | "xl" | undefined;
    gap?: "xs" | "sm" | "md" | "lg" | "xl" | undefined;
    fontSize?: "EM-XXX-SMALL" | "EM-XX-SMALL" | "EM-X-SMALL" | "EM-SMALL" | "EM-MEDIUM" | "EM-LARGE" | "EM-X-LARGE" | "EM-XX-LARGE" | "EM-XXX-LARGE" | "REM-XXX-SMALL" | "REM-XX-SMALL" | "REM-X-SMALL" | "REM-SMALL" | "REM-MEDIUM" | "REM-LARGE" | "REM-X-LARGE" | "REM-XX-LARGE" | "REM-XXX-LARGE" | undefined;
    borderColorName?: "PRIMARY_DARKER" | "PRIMARY_DARK" | "PRIMARY" | "PRIMARY_LIGHT" | "PRIMARY_LIGHTER" | "PRIMARY_LIGHTEST_2" | "PRIMARY_LIGHTEST_1" | "SECONDARY_DARKER" | "SECONDARY_DARK" | "SECONDARY" | "SECONDARY_LIGHT" | "SECONDARY_LIGHTER" | "SECONDARY_LIGHTEST_2" | "SECONDARY_LIGHTEST_1" | "TERTIARY_DARKER" | "TERTIARY_DARK" | "TERTIARY" | "TERTIARY_LIGHT" | "TERTIARY_LIGHTER" | "TERTIARY_LIGHTEST_2" | "TERTIARY_LIGHTEST_1" | "BLACK" | "BLACK2" | "BLACK_LIGHT" | "BLACK_LIGHTER" | "BLACK_LIGHTEST_2" | "BLACK_LIGHTEST_1" | "BLACK_FIX" | "BLACK_FIX_LIGHT" | "BLACK_FIX_LIGHTER" | "BLACK_FIX_LIGHTEST_2" | "BLACK_FIX_LIGHTEST_1" | "WHITE" | "WHITE2" | "WHITE_LIGHT" | "WHITE_LIGHTER" | "WHITE_LIGHTEST_2" | "WHITE_LIGHTEST_1" | "WHITE_FIX" | "WHITE_FIX_LIGHT" | "WHITE_FIX_LIGHTER" | "WHITE_FIX_LIGHTEST_2" | "WHITE_FIX_LIGHTEST_1" | "GRAY_DARKER" | "GRAY_DARK" | "GRAY" | "GRAY_LIGHT" | "GRAY_LIGHTER" | "GRAY_LIGHTEST_2" | "GRAY_LIGHTEST_1" | "SUCCESS_DARKER" | "SUCCESS_DARK" | "SUCCESS" | "SUCCESS_LIGHT" | "SUCCESS_LIGHTER" | "SUCCESS_LIGHTEST_2" | "SUCCESS_LIGHTEST_1" | "WARNING_DARKER" | "WARNING_DARK" | "WARNING" | "WARNING_LIGHT" | "WARNING_LIGHTER" | "WARNING_LIGHTEST_2" | "WARNING_LIGHTEST_1" | "DANGER_DARKER" | "DANGER_DARK" | "DANGER" | "DANGER_LIGHT" | "DANGER_LIGHTER" | "DANGER_LIGHTEST_2" | "DANGER_LIGHTEST_1" | "INFO_DARKER" | "INFO_DARK" | "INFO" | "INFO_LIGHT" | "INFO_LIGHTER" | "INFO_LIGHTEST_2" | "INFO_LIGHTEST_1" | "TRANSPARENT" | "BACKGROUND_DARKER" | "BACKGROUND_DARK" | "BACKGROUND" | "BACKGROUND_LIGHT" | "BACKGROUND_LIGHTER" | "BACKGROUND_LIGHTEST_2" | "BACKGROUND_LIGHTEST_1" | undefined;
    borderColorHex?: string | undefined;
    borderWidth?: number | undefined;
    colorName?: "PRIMARY_DARKER" | "PRIMARY_DARK" | "PRIMARY" | "PRIMARY_LIGHT" | "PRIMARY_LIGHTER" | "PRIMARY_LIGHTEST_2" | "PRIMARY_LIGHTEST_1" | "SECONDARY_DARKER" | "SECONDARY_DARK" | "SECONDARY" | "SECONDARY_LIGHT" | "SECONDARY_LIGHTER" | "SECONDARY_LIGHTEST_2" | "SECONDARY_LIGHTEST_1" | "TERTIARY_DARKER" | "TERTIARY_DARK" | "TERTIARY" | "TERTIARY_LIGHT" | "TERTIARY_LIGHTER" | "TERTIARY_LIGHTEST_2" | "TERTIARY_LIGHTEST_1" | "BLACK" | "BLACK2" | "BLACK_LIGHT" | "BLACK_LIGHTER" | "BLACK_LIGHTEST_2" | "BLACK_LIGHTEST_1" | "BLACK_FIX" | "BLACK_FIX_LIGHT" | "BLACK_FIX_LIGHTER" | "BLACK_FIX_LIGHTEST_2" | "BLACK_FIX_LIGHTEST_1" | "WHITE" | "WHITE2" | "WHITE_LIGHT" | "WHITE_LIGHTER" | "WHITE_LIGHTEST_2" | "WHITE_LIGHTEST_1" | "WHITE_FIX" | "WHITE_FIX_LIGHT" | "WHITE_FIX_LIGHTER" | "WHITE_FIX_LIGHTEST_2" | "WHITE_FIX_LIGHTEST_1" | "GRAY_DARKER" | "GRAY_DARK" | "GRAY" | "GRAY_LIGHT" | "GRAY_LIGHTER" | "GRAY_LIGHTEST_2" | "GRAY_LIGHTEST_1" | "SUCCESS_DARKER" | "SUCCESS_DARK" | "SUCCESS" | "SUCCESS_LIGHT" | "SUCCESS_LIGHTER" | "SUCCESS_LIGHTEST_2" | "SUCCESS_LIGHTEST_1" | "WARNING_DARKER" | "WARNING_DARK" | "WARNING" | "WARNING_LIGHT" | "WARNING_LIGHTER" | "WARNING_LIGHTEST_2" | "WARNING_LIGHTEST_1" | "DANGER_DARKER" | "DANGER_DARK" | "DANGER" | "DANGER_LIGHT" | "DANGER_LIGHTER" | "DANGER_LIGHTEST_2" | "DANGER_LIGHTEST_1" | "INFO_DARKER" | "INFO_DARK" | "INFO" | "INFO_LIGHT" | "INFO_LIGHTER" | "INFO_LIGHTEST_2" | "INFO_LIGHTEST_1" | "TRANSPARENT" | "BACKGROUND_DARKER" | "BACKGROUND_DARK" | "BACKGROUND" | "BACKGROUND_LIGHT" | "BACKGROUND_LIGHTER" | "BACKGROUND_LIGHTEST_2" | "BACKGROUND_LIGHTEST_1" | undefined;
    colorHex?: string | undefined;
    placeholderColorName?: "PRIMARY_DARKER" | "PRIMARY_DARK" | "PRIMARY" | "PRIMARY_LIGHT" | "PRIMARY_LIGHTER" | "PRIMARY_LIGHTEST_2" | "PRIMARY_LIGHTEST_1" | "SECONDARY_DARKER" | "SECONDARY_DARK" | "SECONDARY" | "SECONDARY_LIGHT" | "SECONDARY_LIGHTER" | "SECONDARY_LIGHTEST_2" | "SECONDARY_LIGHTEST_1" | "TERTIARY_DARKER" | "TERTIARY_DARK" | "TERTIARY" | "TERTIARY_LIGHT" | "TERTIARY_LIGHTER" | "TERTIARY_LIGHTEST_2" | "TERTIARY_LIGHTEST_1" | "BLACK" | "BLACK2" | "BLACK_LIGHT" | "BLACK_LIGHTER" | "BLACK_LIGHTEST_2" | "BLACK_LIGHTEST_1" | "BLACK_FIX" | "BLACK_FIX_LIGHT" | "BLACK_FIX_LIGHTER" | "BLACK_FIX_LIGHTEST_2" | "BLACK_FIX_LIGHTEST_1" | "WHITE" | "WHITE2" | "WHITE_LIGHT" | "WHITE_LIGHTER" | "WHITE_LIGHTEST_2" | "WHITE_LIGHTEST_1" | "WHITE_FIX" | "WHITE_FIX_LIGHT" | "WHITE_FIX_LIGHTER" | "WHITE_FIX_LIGHTEST_2" | "WHITE_FIX_LIGHTEST_1" | "GRAY_DARKER" | "GRAY_DARK" | "GRAY" | "GRAY_LIGHT" | "GRAY_LIGHTER" | "GRAY_LIGHTEST_2" | "GRAY_LIGHTEST_1" | "SUCCESS_DARKER" | "SUCCESS_DARK" | "SUCCESS" | "SUCCESS_LIGHT" | "SUCCESS_LIGHTER" | "SUCCESS_LIGHTEST_2" | "SUCCESS_LIGHTEST_1" | "WARNING_DARKER" | "WARNING_DARK" | "WARNING" | "WARNING_LIGHT" | "WARNING_LIGHTER" | "WARNING_LIGHTEST_2" | "WARNING_LIGHTEST_1" | "DANGER_DARKER" | "DANGER_DARK" | "DANGER" | "DANGER_LIGHT" | "DANGER_LIGHTER" | "DANGER_LIGHTEST_2" | "DANGER_LIGHTEST_1" | "INFO_DARKER" | "INFO_DARK" | "INFO" | "INFO_LIGHT" | "INFO_LIGHTER" | "INFO_LIGHTEST_2" | "INFO_LIGHTEST_1" | "TRANSPARENT" | "BACKGROUND_DARKER" | "BACKGROUND_DARK" | "BACKGROUND" | "BACKGROUND_LIGHT" | "BACKGROUND_LIGHTER" | "BACKGROUND_LIGHTEST_2" | "BACKGROUND_LIGHTEST_1" | undefined;
    placeholderColorHex?: string | undefined;
    backgroundColorName?: "PRIMARY_DARKER" | "PRIMARY_DARK" | "PRIMARY" | "PRIMARY_LIGHT" | "PRIMARY_LIGHTER" | "PRIMARY_LIGHTEST_2" | "PRIMARY_LIGHTEST_1" | "SECONDARY_DARKER" | "SECONDARY_DARK" | "SECONDARY" | "SECONDARY_LIGHT" | "SECONDARY_LIGHTER" | "SECONDARY_LIGHTEST_2" | "SECONDARY_LIGHTEST_1" | "TERTIARY_DARKER" | "TERTIARY_DARK" | "TERTIARY" | "TERTIARY_LIGHT" | "TERTIARY_LIGHTER" | "TERTIARY_LIGHTEST_2" | "TERTIARY_LIGHTEST_1" | "BLACK" | "BLACK2" | "BLACK_LIGHT" | "BLACK_LIGHTER" | "BLACK_LIGHTEST_2" | "BLACK_LIGHTEST_1" | "BLACK_FIX" | "BLACK_FIX_LIGHT" | "BLACK_FIX_LIGHTER" | "BLACK_FIX_LIGHTEST_2" | "BLACK_FIX_LIGHTEST_1" | "WHITE" | "WHITE2" | "WHITE_LIGHT" | "WHITE_LIGHTER" | "WHITE_LIGHTEST_2" | "WHITE_LIGHTEST_1" | "WHITE_FIX" | "WHITE_FIX_LIGHT" | "WHITE_FIX_LIGHTER" | "WHITE_FIX_LIGHTEST_2" | "WHITE_FIX_LIGHTEST_1" | "GRAY_DARKER" | "GRAY_DARK" | "GRAY" | "GRAY_LIGHT" | "GRAY_LIGHTER" | "GRAY_LIGHTEST_2" | "GRAY_LIGHTEST_1" | "SUCCESS_DARKER" | "SUCCESS_DARK" | "SUCCESS" | "SUCCESS_LIGHT" | "SUCCESS_LIGHTER" | "SUCCESS_LIGHTEST_2" | "SUCCESS_LIGHTEST_1" | "WARNING_DARKER" | "WARNING_DARK" | "WARNING" | "WARNING_LIGHT" | "WARNING_LIGHTER" | "WARNING_LIGHTEST_2" | "WARNING_LIGHTEST_1" | "DANGER_DARKER" | "DANGER_DARK" | "DANGER" | "DANGER_LIGHT" | "DANGER_LIGHTER" | "DANGER_LIGHTEST_2" | "DANGER_LIGHTEST_1" | "INFO_DARKER" | "INFO_DARK" | "INFO" | "INFO_LIGHT" | "INFO_LIGHTER" | "INFO_LIGHTEST_2" | "INFO_LIGHTEST_1" | "TRANSPARENT" | "BACKGROUND_DARKER" | "BACKGROUND_DARK" | "BACKGROUND" | "BACKGROUND_LIGHT" | "BACKGROUND_LIGHTER" | "BACKGROUND_LIGHTEST_2" | "BACKGROUND_LIGHTEST_1" | undefined;
    backgroundColorHex?: string | undefined;
    textError?: string | undefined;
    onChange?: ((values: string[]) => void) | undefined;
    autoComplete?: string | undefined;
    LeftIcon?: FC<IconProps> | undefined;
    RightIcon?: FC<IconProps> | undefined;
    leftIconColorName?: "PRIMARY_DARKER" | "PRIMARY_DARK" | "PRIMARY" | "PRIMARY_LIGHT" | "PRIMARY_LIGHTER" | "PRIMARY_LIGHTEST_2" | "PRIMARY_LIGHTEST_1" | "SECONDARY_DARKER" | "SECONDARY_DARK" | "SECONDARY" | "SECONDARY_LIGHT" | "SECONDARY_LIGHTER" | "SECONDARY_LIGHTEST_2" | "SECONDARY_LIGHTEST_1" | "TERTIARY_DARKER" | "TERTIARY_DARK" | "TERTIARY" | "TERTIARY_LIGHT" | "TERTIARY_LIGHTER" | "TERTIARY_LIGHTEST_2" | "TERTIARY_LIGHTEST_1" | "BLACK" | "BLACK2" | "BLACK_LIGHT" | "BLACK_LIGHTER" | "BLACK_LIGHTEST_2" | "BLACK_LIGHTEST_1" | "BLACK_FIX" | "BLACK_FIX_LIGHT" | "BLACK_FIX_LIGHTER" | "BLACK_FIX_LIGHTEST_2" | "BLACK_FIX_LIGHTEST_1" | "WHITE" | "WHITE2" | "WHITE_LIGHT" | "WHITE_LIGHTER" | "WHITE_LIGHTEST_2" | "WHITE_LIGHTEST_1" | "WHITE_FIX" | "WHITE_FIX_LIGHT" | "WHITE_FIX_LIGHTER" | "WHITE_FIX_LIGHTEST_2" | "WHITE_FIX_LIGHTEST_1" | "GRAY_DARKER" | "GRAY_DARK" | "GRAY" | "GRAY_LIGHT" | "GRAY_LIGHTER" | "GRAY_LIGHTEST_2" | "GRAY_LIGHTEST_1" | "SUCCESS_DARKER" | "SUCCESS_DARK" | "SUCCESS" | "SUCCESS_LIGHT" | "SUCCESS_LIGHTER" | "SUCCESS_LIGHTEST_2" | "SUCCESS_LIGHTEST_1" | "WARNING_DARKER" | "WARNING_DARK" | "WARNING" | "WARNING_LIGHT" | "WARNING_LIGHTER" | "WARNING_LIGHTEST_2" | "WARNING_LIGHTEST_1" | "DANGER_DARKER" | "DANGER_DARK" | "DANGER" | "DANGER_LIGHT" | "DANGER_LIGHTER" | "DANGER_LIGHTEST_2" | "DANGER_LIGHTEST_1" | "INFO_DARKER" | "INFO_DARK" | "INFO" | "INFO_LIGHT" | "INFO_LIGHTER" | "INFO_LIGHTEST_2" | "INFO_LIGHTEST_1" | "TRANSPARENT" | "BACKGROUND_DARKER" | "BACKGROUND_DARK" | "BACKGROUND" | "BACKGROUND_LIGHT" | "BACKGROUND_LIGHTER" | "BACKGROUND_LIGHTEST_2" | "BACKGROUND_LIGHTEST_1" | undefined;
    leftIconColorHex?: string | undefined;
    rightIconColorName?: "PRIMARY_DARKER" | "PRIMARY_DARK" | "PRIMARY" | "PRIMARY_LIGHT" | "PRIMARY_LIGHTER" | "PRIMARY_LIGHTEST_2" | "PRIMARY_LIGHTEST_1" | "SECONDARY_DARKER" | "SECONDARY_DARK" | "SECONDARY" | "SECONDARY_LIGHT" | "SECONDARY_LIGHTER" | "SECONDARY_LIGHTEST_2" | "SECONDARY_LIGHTEST_1" | "TERTIARY_DARKER" | "TERTIARY_DARK" | "TERTIARY" | "TERTIARY_LIGHT" | "TERTIARY_LIGHTER" | "TERTIARY_LIGHTEST_2" | "TERTIARY_LIGHTEST_1" | "BLACK" | "BLACK2" | "BLACK_LIGHT" | "BLACK_LIGHTER" | "BLACK_LIGHTEST_2" | "BLACK_LIGHTEST_1" | "BLACK_FIX" | "BLACK_FIX_LIGHT" | "BLACK_FIX_LIGHTER" | "BLACK_FIX_LIGHTEST_2" | "BLACK_FIX_LIGHTEST_1" | "WHITE" | "WHITE2" | "WHITE_LIGHT" | "WHITE_LIGHTER" | "WHITE_LIGHTEST_2" | "WHITE_LIGHTEST_1" | "WHITE_FIX" | "WHITE_FIX_LIGHT" | "WHITE_FIX_LIGHTER" | "WHITE_FIX_LIGHTEST_2" | "WHITE_FIX_LIGHTEST_1" | "GRAY_DARKER" | "GRAY_DARK" | "GRAY" | "GRAY_LIGHT" | "GRAY_LIGHTER" | "GRAY_LIGHTEST_2" | "GRAY_LIGHTEST_1" | "SUCCESS_DARKER" | "SUCCESS_DARK" | "SUCCESS" | "SUCCESS_LIGHT" | "SUCCESS_LIGHTER" | "SUCCESS_LIGHTEST_2" | "SUCCESS_LIGHTEST_1" | "WARNING_DARKER" | "WARNING_DARK" | "WARNING" | "WARNING_LIGHT" | "WARNING_LIGHTER" | "WARNING_LIGHTEST_2" | "WARNING_LIGHTEST_1" | "DANGER_DARKER" | "DANGER_DARK" | "DANGER" | "DANGER_LIGHT" | "DANGER_LIGHTER" | "DANGER_LIGHTEST_2" | "DANGER_LIGHTEST_1" | "INFO_DARKER" | "INFO_DARK" | "INFO" | "INFO_LIGHT" | "INFO_LIGHTER" | "INFO_LIGHTEST_2" | "INFO_LIGHTEST_1" | "TRANSPARENT" | "BACKGROUND_DARKER" | "BACKGROUND_DARK" | "BACKGROUND" | "BACKGROUND_LIGHT" | "BACKGROUND_LIGHTER" | "BACKGROUND_LIGHTEST_2" | "BACKGROUND_LIGHTEST_1" | undefined;
    rightIconColorHex?: string | undefined;
    leftIconSize?: number | undefined;
    rightIconSize?: number | undefined;
    leftChildren?: ReactNode;
    rightChildren?: ReactNode;
    min?: number | undefined;
    max?: number | undefined;
    outline?: boolean | undefined;
    description?: string | undefined;
    width?: string | number | undefined;
    maxWidth?: string | number | undefined;
    minWidth?: string | number | undefined;
    info?: ReactNode;
    data?: DOMStringMap | undefined;
    type?: "number" | "time" | "text" | "search" | "color" | "hidden" | "date" | "datetime-local" | "email" | "month" | "password" | "tel" | "url" | "week" | undefined;
    defaultValues?: string[] | undefined;
} & react.RefAttributes<HTMLInputElement>>;

export { MultiInputField, MultiInputFieldCSS, MultiInputFieldGap, MultiInputFieldPadding, MultiInputFieldProps, MultiInputFieldType, multiInputFieldGap, multiInputFieldPadding, multiInputFieldType };
